@@ -1,6 +1,6 @@
 /* application.c
  *
- * Copyright (C) 2008-2024 John Stebbins <stebbins@stebbins>
+ * Copyright (C) 2008-2025 John Stebbins <stebbins@stebbins>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -568,6 +568,7 @@ _ghb_idle_ui_init (signal_user_data_t *ud)
     }
 
     ghb_bind_dependencies();
+    ghb_check_send_to_available();
 
     return FALSE;
 }
@@ -587,10 +588,8 @@ static gboolean
 video_file_drop_received (GtkDropTarget* self, const GValue* value,
                           double x, double y, signal_user_data_t *ud)
 {
-/* The GdkFileList method is preferred where supported as it handles multiple
+/* The GdkFileList method is preferred as it handles multiple
  * files and also allows access to sandboxed files via the portal */
-#if GTK_CHECK_VERSION(4, 6, 0)
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     if (G_VALUE_HOLDS(value, GDK_TYPE_FILE_LIST))
     {
         GdkFileList *gdk_file_list = g_value_get_boxed(value);
@@ -628,8 +627,6 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         }
         return TRUE;
     }
-G_GNUC_END_IGNORE_DEPRECATIONS
-#endif
 
     g_autoptr(GFile) file = NULL;
     g_autofree gchar *filename = NULL;
@@ -666,9 +663,7 @@ video_file_drop_init (signal_user_data_t *ud)
 {
     GtkWidget *window = ghb_builder_widget("hb_window");
     GType types[] = {
-#if GTK_CHECK_VERSION(4, 6, 0)
         GDK_TYPE_FILE_LIST,
-#endif
         G_TYPE_FILE,
         G_TYPE_URI,
     };
@@ -762,19 +757,6 @@ ghb_application_activate (GApplication *app)
     signal_user_data_t *ud = self->ud = g_malloc0(sizeof(signal_user_data_t));
     g_autoptr(GtkCssProvider) provider = gtk_css_provider_new();
 
-    if (ghb_dict_get_bool(ud->prefs, "CustomTmpEnable"))
-    {
-        const char *tmp_dir = ghb_dict_get_string(ud->prefs, "CustomTmpDir");
-        if (tmp_dir != NULL && tmp_dir[0] != 0)
-        {
-#if defined(_WIN32)
-           _putenv_s("TEMP", tmp_dir);
-#else
-            setenv("TEMP", tmp_dir, 1);
-#endif
-        }
-    }
-
     gtk_css_provider_load_from_resource(provider, "/fr/handbrake/ghb/ui/custom.css");
     color_scheme_set_async(APP_PREFERS_LIGHT);
 
@@ -860,6 +842,15 @@ ghb_application_activate (GApplication *app)
     // Store user preferences into ud->prefs
     ghb_prefs_to_settings(ud->prefs);
 
+    if (ghb_dict_get_bool(ud->prefs, "CustomTmpEnable"))
+    {
+        const char *tmp_dir = ghb_dict_get_string(ud->prefs, "CustomTmpDir");
+        if (tmp_dir != NULL && tmp_dir[0] != 0)
+        {
+            hb_set_temporary_directory(tmp_dir);
+        }
+    }
+
     int logLevel = ghb_dict_get_int(ud->prefs, "LoggingLevel");
 
     // Initialize HB work threads
@@ -973,10 +964,8 @@ ghb_application_handle_local_options (GApplication *app, GVariantDict *options)
     if (g_variant_dict_lookup(options, "config", "s", &config_dir))
         ghb_override_user_config_dir(config_dir);
 
-#if GLIB_CHECK_VERSION(2, 72, 0)
     if (g_variant_dict_lookup(options, "debug", "b", NULL))
         g_log_set_debug_enabled(TRUE);
-#endif
 
     if (g_variant_dict_lookup(options, "console", "b", NULL))
 #if defined(_WIN32)
