@@ -1,6 +1,6 @@
 /* queuehandler.c
  *
- * Copyright (C) 2008-2024 John Stebbins <stebbins@stebbins>
+ * Copyright (C) 2008-2025 John Stebbins <stebbins@stebbins>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -1661,6 +1661,25 @@ queue_remove_response (GtkWidget *dialog, int response, GhbQueueRow *queue_row)
     int queue_remove_unique_id = ghb_dict_get_int(uiDict, "job_unique_id");
     int status = ghb_dict_get_int(uiDict, "job_status");
 
+    // Update UI
+    GtkListBox *lb = GTK_LIST_BOX(ghb_builder_widget("queue_list"));
+    GtkListBoxRow *selected_row = gtk_list_box_get_selected_row(lb);
+    int selected_index = gtk_list_box_row_get_index(selected_row);
+    if (selected_row == row)
+    {
+        // Select the row after the row to delete
+        selected_row = gtk_list_box_get_row_at_index(lb, selected_index + 1);
+    }
+    if (selected_row == NULL)
+    {
+        // The row to delete is the last one, try the one before it
+        selected_row = gtk_list_box_get_row_at_index(lb, selected_index - 1);
+    }
+    if (selected_row != NULL)
+    {
+        gtk_list_box_select_row(lb, selected_row);
+    }
+    gtk_list_box_remove(lb, GTK_WIDGET(row));
     ghb_array_remove(ud->queue, queue_remove_index);
 
     if (status == GHB_QUEUE_RUNNING)
@@ -1669,19 +1688,6 @@ queue_remove_response (GtkWidget *dialog, int response, GhbQueueRow *queue_row)
         ghb_set_cancel_status(GHB_CANCEL_ALL);
         ghb_remove_job(queue_remove_unique_id);
     }
-
-    // Update UI
-    GtkListBox *lb = GTK_LIST_BOX(ghb_builder_widget("queue_list"));
-    gtk_list_box_remove(lb, GTK_WIDGET(row));
-
-    if (queue_remove_index >= 1)
-    {
-        row = gtk_list_box_get_row_at_index(lb, queue_remove_index - 1);
-    }
-    if (row != NULL)
-    {
-        gtk_list_box_select_row(lb, row);
-    }
 }
 
 static void
@@ -1696,7 +1702,7 @@ queue_remove_dialog_show (GhbQueueRow *row)
                 _("Cancel and Remove"), NULL, NULL, _("Continue Encoding"));
 
     g_signal_connect(dialog, "response", G_CALLBACK(queue_remove_response), row);
-    gtk_widget_show(dialog);
+    gtk_widget_set_visible(dialog, TRUE);
 }
 
 static void
@@ -2070,13 +2076,6 @@ queue_show_sidebar_action_cb (GSimpleAction *action, GVariant *param,
     g_simple_action_set_state(action, param);
 }
 
-G_MODULE_EXPORT gboolean
-queue_window_delete_cb (GtkWidget *xwidget, gpointer data)
-{
-    gtk_widget_set_visible(xwidget, FALSE);
-    return TRUE;
-}
-
 GhbValue *ghb_queue_edit_settings = NULL;
 
 G_MODULE_EXPORT void
