@@ -1,6 +1,6 @@
 /* title-add.c
  *
- * Copyright (C) 2008-2024 John Stebbins <stebbins@stebbins>
+ * Copyright (C) 2008-2025 John Stebbins <stebbins@stebbins>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -290,26 +290,32 @@ static PangoAttrList *default_title_attrs;
 static void
 title_add_set_sensitive (GtkWidget *row, gboolean sensitive)
 {
+    PangoAttrList *pal;
+    PangoAttribute *bg, *alpha;
     GtkWidget *widget;
     widget = find_widget(row, "title_selected");
     gtk_widget_set_sensitive(widget, sensitive);
 
     widget = find_widget(row, "title_label");
+
     if (!sensitive)
     {
-        PangoAttrList *pal;
-        PangoAttribute *bg;
-        bg = pango_attr_background_new(0xFFFF, 0xFFFF, 0xA000);
-        pal = pango_attr_list_new();
-        pango_attr_list_insert(pal, bg);
-        gtk_label_set_attributes(GTK_LABEL(widget), pal);
+        alpha = pango_attr_background_alpha_new(0);
         gtk_widget_set_has_tooltip(widget, TRUE);
     }
     else
     {
+        alpha = pango_attr_background_alpha_new(1);
         gtk_label_set_attributes(GTK_LABEL(widget), default_title_attrs);
         gtk_widget_set_has_tooltip(widget, FALSE);
     }
+
+    pal = pango_attr_list_new();
+    bg = pango_attr_background_new(0xFFFF, 0xFFFF, 0xA000);
+    pango_attr_list_insert(pal, bg);
+    pango_attr_list_insert(pal, alpha);
+
+    gtk_label_set_attributes(GTK_LABEL(widget), pal);
 }
 
 static gboolean
@@ -430,7 +436,7 @@ static GtkWidget *title_create_row (signal_user_data_t *ud)
     gtk_box_set_spacing(hbox, 6);
     gtk_widget_set_margin_start(GTK_WIDGET(hbox), 6);
     gtk_widget_set_margin_end(GTK_WIDGET(hbox), 6);
-    gtk_widget_show(GTK_WIDGET(hbox));
+    gtk_widget_set_visible(GTK_WIDGET(hbox), TRUE);
 
     // Select checkbox
     selected = GTK_CHECK_BUTTON(gtk_check_button_new());
@@ -439,7 +445,7 @@ static GtkWidget *title_create_row (signal_user_data_t *ud)
       _("Select this title for adding to the queue.\n"));
     gtk_widget_set_valign(GTK_WIDGET(selected), GTK_ALIGN_CENTER);
     gtk_widget_set_name(GTK_WIDGET(selected), "title_selected");
-    gtk_widget_show(GTK_WIDGET(selected));
+    gtk_widget_set_visible(GTK_WIDGET(selected), TRUE);
     g_signal_connect(selected, "toggled", (GCallback)title_selected_cb, ud);
     gtk_box_append(hbox, GTK_WIDGET(selected));
 
@@ -449,7 +455,7 @@ static GtkWidget *title_create_row (signal_user_data_t *ud)
     gtk_widget_set_halign(GTK_WIDGET(title), GTK_ALIGN_START);
     gtk_widget_set_valign(GTK_WIDGET(title), GTK_ALIGN_CENTER);
     gtk_widget_set_name(GTK_WIDGET(title), "title_label");
-    gtk_widget_show(GTK_WIDGET(title));
+    gtk_widget_set_visible(GTK_WIDGET(title), TRUE);
     gtk_box_append(hbox, GTK_WIDGET(title));
 
     default_title_attrs = gtk_label_get_attributes(title);
@@ -468,7 +474,7 @@ static GtkWidget *title_create_row (signal_user_data_t *ud)
     gtk_editable_set_width_chars(GTK_EDITABLE(dest_file), 40);
     gtk_widget_set_name(dest_file, "title_file");
     //gtk_widget_set_hexpand(dest_file, TRUE);
-    gtk_widget_show(dest_file);
+    gtk_widget_set_visible(dest_file, TRUE);
     g_signal_connect(dest_file, "changed", (GCallback)title_dest_file_cb, ud);
     gtk_box_append(vbox_dest, dest_file);
     dest_dir = ghb_file_button_new(_("Destination Directory"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
@@ -476,9 +482,9 @@ static GtkWidget *title_create_row (signal_user_data_t *ud)
                      G_CALLBACK(title_dest_dir_cb), ud);
     gtk_widget_set_name(GTK_WIDGET(dest_dir), "title_dir");
     gtk_widget_set_hexpand(GTK_WIDGET(dest_dir), TRUE);
-    gtk_widget_show(GTK_WIDGET(dest_dir));
+    gtk_widget_set_visible(GTK_WIDGET(dest_dir), TRUE);
     gtk_box_append(vbox_dest, GTK_WIDGET(dest_dir));
-    gtk_widget_show(GTK_WIDGET(vbox_dest));
+    gtk_widget_set_visible(GTK_WIDGET(vbox_dest), TRUE);
     gtk_box_append(hbox, GTK_WIDGET(vbox_dest));
 
     return GTK_WIDGET(hbox);
