@@ -1,6 +1,6 @@
 /* avfilter.c
 
-   Copyright (c) 2003-2015 HandBrake Team
+   Copyright (c) 2003-2025 HandBrake Team
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -11,10 +11,6 @@
 #include "handbrake/hbavfilter.h"
 #include "handbrake/avfilter_priv.h"
 
-#if HB_PROJECT_FEATURE_QSV && (defined( _WIN32 ) || defined( __MINGW32__ ))
-#include "handbrake/qsv_common.h"
-#endif
-
 static int  avfilter_init(hb_filter_object_t * filter, hb_filter_init_t * init);
 static int  avfilter_post_init( hb_filter_object_t * filter, hb_job_t * job );
 static void avfilter_close( hb_filter_object_t * filter );
@@ -238,22 +234,6 @@ static hb_buffer_t* filterFrame( hb_filter_private_t * pv, hb_buffer_t ** buf_in
     hb_buffer_list_t   list;
     hb_buffer_t      * buf = NULL, * next = NULL;
 
-#if HB_PROJECT_FEATURE_QSV && (defined( _WIN32 ) || defined( __MINGW32__ ))
-    mfxFrameSurface1 *surface = NULL;
-    HBQSVFramesContext *frames_ctx = NULL;
-    if (hb_qsv_hw_filters_via_video_memory_are_enabled(pv->input.job) && buf_in != NULL)
-    {
-        hb_buffer_t *in = *buf_in;
-        AVFrame *frame = (AVFrame *)in->storage;
-        if (frame)
-        {
-            // We need to keep surface pointer because hb_avfilter_add_buf set it to 0 after in ffmpeg call
-            surface = (mfxFrameSurface1 *)frame->data[3];
-            frames_ctx = in->qsv_details.qsv_frames_ctx;
-        }
-    }
-#endif
-
     hb_avfilter_add_buf(pv->graph, buf_in);
     buf = hb_avfilter_get_buf(pv->graph);
 
@@ -262,12 +242,6 @@ static hb_buffer_t* filterFrame( hb_filter_private_t * pv, hb_buffer_t ** buf_in
         hb_buffer_list_append(&pv->list, buf);
         buf = hb_avfilter_get_buf(pv->graph);
     }
-#if HB_PROJECT_FEATURE_QSV && (defined( _WIN32 ) || defined( __MINGW32__ ))
-    if (hb_qsv_hw_filters_via_video_memory_are_enabled(pv->input.job) && surface)
-    {
-        hb_qsv_release_surface_from_pool_by_surface_pointer(frames_ctx, surface);
-    }
-#endif
     // Delay one frame so we can set the stop time of the output buffer
     hb_buffer_list_clear(&list);
     while (hb_buffer_list_count(&pv->list) > 1)
