@@ -1,6 +1,6 @@
 /* decssasub.c
 
-   Copyright (c) 2003-2024 HandBrake Team
+   Copyright (c) 2003-2025 HandBrake Team
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -31,11 +31,11 @@
 
 struct hb_work_private_s
 {
-    AVFormatContext    * ic;
-    hb_avsub_context_t * ctx;
-    AVPacket           * pkt;
-    hb_job_t           * job;
-    hb_subtitle_t      * subtitle;
+    AVFormatContext       * ic;
+    hb_decavsub_context_t * ctx;
+    AVPacket              * pkt;
+    hb_job_t              * job;
+    hb_subtitle_t         * subtitle;
 
     // Time of first desired subtitle adjusted by reader_pts_offset
     uint64_t start_time;
@@ -58,7 +58,7 @@ static int extradataInit( hb_work_private_t * pv )
     }
     if (st->codecpar->extradata != NULL)
     {
-        hb_set_text_extradata(&pv->subtitle->extradata, st->codecpar->extradata, st->codecpar->extradata_size);
+        hb_set_extradata(&pv->subtitle->extradata, st->codecpar->extradata, st->codecpar->extradata_size);
     }
     return 0;
 }
@@ -108,6 +108,12 @@ static int decssaInit( hb_work_object_t * w, hb_job_t * job )
         goto fail;
     }
 
+    pv->ctx = decavsubInit(w, job);
+    if (pv->ctx == NULL)
+    {
+        goto fail;
+    }
+
     /*
      * Figure out the start and stop times from the chapters being
      * encoded - drop subtitle not in this range.
