@@ -1,6 +1,6 @@
 /* format.c
 
-   Copyright (c) 2003-2023 HandBrake Team
+   Copyright (c) 2003-2025 HandBrake Team
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -9,11 +9,6 @@
 
 #include "handbrake/common.h"
 #include "handbrake/avfilter_priv.h"
-#if HB_PROJECT_FEATURE_QSV && (defined( _WIN32 ) || defined( __MINGW32__ ))
-#include "handbrake/qsv_common.h"
-#include "libavutil/hwcontext_qsv.h"
-#include "libavutil/hwcontext.h"
-#endif
 
 static int format_init(hb_filter_object_t *filter,
                            hb_filter_init_t *init);
@@ -61,32 +56,29 @@ static int format_init(hb_filter_object_t *filter, hb_filter_init_t *init)
     hb_dict_t *avsettings = hb_dict_init();
 
 #if HB_PROJECT_FEATURE_QSV && (defined( _WIN32 ) || defined( __MINGW32__ ))
-    if (hb_qsv_full_path_is_enabled(init->job))
+    if (init->hw_pix_fmt == AV_PIX_FMT_QSV)
     {
-        init->job->qsv.ctx->num_hw_filters++;
         hb_dict_set_string(avsettings, "format", format);
-        hb_dict_set_int(avsettings, "async_depth", init->job->qsv.async_depth);
-        init->pix_fmt = av_get_pix_fmt(format);
+        hb_dict_set_string(avsettings, "out_range", (init->color_range == AVCOL_RANGE_JPEG) ? "full" : "limited");
+        hb_dict_set_int(avsettings, "async_depth", init->job->hw_device_async_depth);
 
-        if (init->job->qsv.ctx->out_range != AVCOL_RANGE_UNSPECIFIED)
-            hb_dict_set_string(avsettings, "out_range", (init->job->qsv.ctx->out_range == AVCOL_RANGE_JPEG) ? "full" : "limited");
-
-        if (hb_qsv_hw_filters_via_video_memory_are_enabled(init->job))
-        {
-            int result = hb_qsv_create_ffmpeg_vpp_pool(init, init->geometry.width, init->geometry.height);
-            if (result < 0)
-            {
-                hb_error("hb_create_ffmpeg_pool vpp allocation failed");
-                return result;
-            }
-        }
         hb_dict_set(avfilter, "vpp_qsv", avsettings);
     }
     else
 #endif
     {
-        hb_dict_set_string(avsettings, "pix_fmts", format);
-        hb_dict_set(avfilter, "format", avsettings);
+        if (init->hw_pix_fmt == AV_PIX_FMT_CUDA)
+        {
+            hb_dict_set_int(avsettings, "w", init->geometry.width);
+            hb_dict_set_int(avsettings, "h", init->geometry.height);
+            hb_dict_set_string(avsettings, "format", format);
+            hb_dict_set(avfilter, "scale_cuda", avsettings);
+        }
+        else
+        {
+            hb_dict_set_string(avsettings, "pix_fmts", format);
+            hb_dict_set(avfilter, "format", avsettings);
+        }
     }
 
     hb_value_array_append(avfilters, avfilter);
