@@ -1,6 +1,6 @@
 /* cv_utils.h
 
-   Copyright (c) 2003-2024 HandBrake Team
+   Copyright (c) 2003-2025 HandBrake Team
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -18,6 +18,9 @@ OSType hb_cv_get_pixel_format(enum AVPixelFormat pix_fmt,
 
 CVPixelBufferRef hb_cv_get_pixel_buffer(const hb_buffer_t *buf);
 
+int hb_cv_get_io_surface_usage_count(const hb_buffer_t *buf);
+
+
 CVPixelBufferPoolRef hb_cv_create_pixel_buffer_pool(int width, int height,
                                                     enum AVPixelFormat pix_fmt,
                                                     enum AVColorRange color_range);
@@ -29,10 +32,12 @@ CFStringRef hb_cv_colr_mat_xlat(int color_matrix);
 CFStringRef hb_cv_colr_range_xlat(int color_range);
 CFStringRef hb_cv_chroma_loc_xlat(int chroma_location);
 
-void hb_cv_add_color_tag(CVPixelBufferRef pix_buf,
+void hb_cv_add_color_tag(CFMutableDictionaryRef attachments,
                          int color_prim, int color_transfer,
                          int color_matrix, int chroma_location);
 
+void hb_cv_set_attachments(CVPixelBufferRef pix_buf, CFDictionaryRef attachments);
+
 int hb_cv_match_rgb_to_colorspace(int rgb,
                                   int color_prim,
                                   int color_transfer,
