@@ -1,6 +1,6 @@
 /* grayscale_vt.m
 
-   Copyright (c) 2003-2024 HandBrake Team
+   Copyright (c) 2003-2025 HandBrake Team
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -196,13 +196,13 @@ static hb_buffer_t * filter_frame(hb_filter_private_t *pv, hb_buffer_t *in)
             continue;
         }
 
-        format[i] = hb_metal_pix_fmt_from_component(comp, &channels);
+        format[i] = hb_metal_pix_fmt_from_component(comp, 0, &channels);
         if (format[i] == MTLPixelFormatInvalid)
         {
             goto fail;
         }
 
-        src[i]     = hb_metal_create_texture_from_pixbuf(pv->mtl->cache, cv_src, i, format[i]);
+        src[i]     = hb_metal_create_texture_from_pixbuf(pv->mtl->cache, cv_src, i, channels, format[i]);
         tex_src[i] = CVMetalTextureGetTexture(src[i]);
     }
 
@@ -214,7 +214,7 @@ static hb_buffer_t * filter_frame(hb_filter_private_t *pv, hb_buffer_t *in)
             continue;
         }
 
-        CVMetalTextureRef dest = hb_metal_create_texture_from_pixbuf(pv->mtl->cache, cv_dest, i, format[i]);
+        CVMetalTextureRef dest = hb_metal_create_texture_from_pixbuf(pv->mtl->cache, cv_dest, i, channels, format[i]);
         id<MTLTexture> tex_dest = CVMetalTextureGetTexture(dest);
 
         call_kernel(pv, tex_dest, tex_src, i);
@@ -230,7 +230,9 @@ static hb_buffer_t * filter_frame(hb_filter_private_t *pv, hb_buffer_t *in)
         }
     }
 
+#if defined(HB_VT_PROPAGATE_ATTACHMENTS)
     CVBufferPropagateAttachments(cv_src, cv_dest);
+#endif
 
     out = hb_buffer_wrapper_init();
     out->storage_type      = COREMEDIA;
