@@ -1,6 +1,6 @@
 /* prefilter_vt.c
 
-   Copyright (c) 2003-2024 HandBrake Team
+   Copyright (c) 2003-2025 HandBrake Team
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -19,11 +19,14 @@ struct hb_filter_private_s
     hb_fifo_t *fifo_first;
     hb_fifo_t *fifo_last;
 
+    int rotation;
+
     struct
     {
         int width;
         int height;
         int rotation;
+        int color_range;
         int pix_fmt;
     } resample;
 
@@ -31,29 +34,6 @@ struct hb_filter_private_s
     int done;
 };
 
-static int prefilter_vt_init(hb_filter_object_t *filter,
-                              hb_filter_init_t   *init);
-
-static int prefilter_vt_work(hb_filter_object_t *filter,
-                              hb_buffer_t **buf_in,
-                              hb_buffer_t **buf_out);
-
-static void prefilter_vt_close(hb_filter_object_t *filter);
-
-static const char prefilter_vt_template[] = "";
-
-hb_filter_object_t hb_filter_prefilter_vt =
-{
-    .id                = HB_FILTER_PRE_VT,
-    .enforce_order     = 1,
-    .name              = "Prefilter (VideoToolbox)",
-    .settings          = NULL,
-    .init              = prefilter_vt_init,
-    .work              = prefilter_vt_work,
-    .close             = prefilter_vt_close,
-    .settings_template = prefilter_vt_template,
-};
-
 static int prefilter_vt_init(hb_filter_object_t *filter, hb_filter_init_t *init)
 {
     filter->private_data = calloc(sizeof(struct hb_filter_private_s), 1);
@@ -64,7 +44,16 @@ static int prefilter_vt_init(hb_filter_object_t *filter, hb_filter_init_t *init)
     }
     hb_filter_private_t *pv = filter->private_data;
 
-    pv->input = *init;
+    int rotation = 0;
+    hb_dict_t *settings = filter->settings;
+
+    hb_dict_extract_int(&rotation, settings, "rotation");
+    if (rotation >= HB_ROTATION_0 && rotation <= HB_ROTATION_270)
+    {
+        pv->rotation = rotation;
+    }
+
+    pv->input  = *init;
     pv->output = *init;
 
     return 0;
@@ -113,8 +102,8 @@ static void prefilter_vt_close(hb_filter_object_t *filter)
 
 static void set_properties(hb_filter_private_t *pv, hb_buffer_t *in)
 {
-    if (pv->input.job->title->rotation == HB_ROTATION_90 ||
-        pv->input.job->title->rotation == HB_ROTATION_270)
+    if (pv->rotation == HB_ROTATION_90 ||
+        pv->rotation == HB_ROTATION_270)
     {
         pv->input.geometry.width  = in->f.height;
         pv->input.geometry.height = in->f.width;
@@ -125,6 +114,8 @@ static void set_properties(hb_filter_private_t *pv, hb_buffer_t *in)
         pv->input.geometry.height = in->f.height;
     }
 
+    pv->input.color_range = in->f.color_range;
+
     if (in->storage_type == AVFRAME)
     {
         AVFrame *frame = (AVFrame *)in->storage;
@@ -133,11 +124,11 @@ static void set_properties(hb_filter_private_t *pv, hb_buffer_t *in)
         if (frame->hw_frames_ctx)
         {
             AVHWFramesContext *frames_ctx = (AVHWFramesContext *)frame->hw_frames_ctx->data;
-            pv->input.pix_fmt    = frames_ctx->sw_format;
+            pv->input.pix_fmt = frames_ctx->sw_format;
         }
         else
         {
-            pv->input.pix_fmt    = frame->format;
+            pv->input.pix_fmt = frame->format;
         }
     }
     else
@@ -170,10 +161,10 @@ static void process_filter(hb_filter_object_t *filter)
 
 static hb_buffer_t * filter_buf(hb_filter_private_t *pv, hb_buffer_t *in)
 {
-    // Feed preview frame to filter chain
+    // Feed frame to filter chain
     hb_fifo_push(pv->fifo_first, in);
 
-    // Process the preview frame through all filters
+    // Process the frame through all filters
     for (int ii = 0; ii < hb_list_count(pv->list_filter); ii++)
     {
         hb_filter_object_t *filter = hb_list_item(pv->list_filter, ii);
@@ -182,44 +173,44 @@ static hb_buffer_t * filter_buf(hb_filter_private_t *pv, hb_buffer_t *in)
             process_filter(filter);
         }
     }
-    // Retrieve the filtered preview frame
+    // Retrieve the filtered frame
     return hb_fifo_get(pv->fifo_last);
 }
 
-static int update(hb_filter_private_t *pv)
+static int update_filters(hb_filter_private_t *pv)
 {
     int resample_changed;
-    hb_job_t *job = pv->input.job;
 
     pv->resample_needed =
         (pv->output.geometry.width  != pv->input.geometry.width  ||
          pv->output.geometry.height != pv->input.geometry.height ||
-         pv->output.pix_fmt   != pv->input.pix_fmt ||
-         job->title->rotation != HB_ROTATION_0);
+         pv->output.color_range     != pv->input.color_range ||
+         pv->output.pix_fmt         != pv->input.pix_fmt ||
+         pv->rotation               != HB_ROTATION_0);
 
     resample_changed =
         (pv->resample_needed &&
-         (pv->resample.width    != pv->input.geometry.width  ||
-          pv->resample.height   != pv->input.geometry.height ||
-          pv->resample.pix_fmt  != pv->input.pix_fmt ||
-          pv->resample.rotation != job->title->rotation));
+         (pv->resample.width       != pv->input.geometry.width  ||
+          pv->resample.height      != pv->input.geometry.height ||
+          pv->resample.color_range != pv->input.color_range ||
+          pv->resample.pix_fmt     != pv->input.pix_fmt ||
+          pv->resample.rotation    != pv->rotation));
 
-    if (resample_changed || (pv->resample_needed &&
-                             pv->list_filter == NULL))
+    if (resample_changed || (pv->resample_needed && pv->list_filter == NULL))
     {
         close_filters(pv);
-        hb_list_t *list_filter  = hb_list_init();
+        hb_list_t *list_filter = hb_list_init();
         hb_filter_init_t init = pv->input;
 
         hb_filter_object_t *filter;
 
         // Rotate
-        if (job->title->rotation != HB_ROTATION_0)
+        if (pv->rotation != HB_ROTATION_0)
         {
             filter = hb_filter_init(HB_FILTER_ROTATE_VT);
             filter->settings = hb_dict_init();
 
-            switch (job->title->rotation)
+            switch (pv->rotation)
             {
                 case HB_ROTATION_90:
                     hb_dict_set(filter->settings, "angle", hb_value_string("270"));
@@ -237,6 +228,13 @@ static int update(hb_filter_private_t *pv)
                     hb_log("prefilter_vt: reinit_video_filters: unknown rotation, failed");
             }
 
+            if (pv->rotation == HB_ROTATION_90 ||
+                pv->rotation == HB_ROTATION_270)
+            {
+                init.geometry.width  = pv->input.geometry.height;
+                init.geometry.height = pv->input.geometry.width;
+            }
+
             hb_list_add(list_filter, filter);
             if (filter->init != NULL && filter->init(filter, &init))
             {
@@ -249,6 +247,7 @@ static int update(hb_filter_private_t *pv)
         // Crop Scale & Format
         if (pv->output.geometry.width  != pv->input.geometry.width  ||
             pv->output.geometry.height != pv->input.geometry.height ||
+            pv->output.color_range     != pv->input.color_range     ||
             pv->output.pix_fmt         != pv->input.pix_fmt)
         {
             filter = hb_filter_init(HB_FILTER_CROP_SCALE_VT);
@@ -271,6 +270,12 @@ static int update(hb_filter_private_t *pv)
                 hb_log("prefilter_vt: converting video pixel format from %s", av_get_pix_fmt_name(pv->input.pix_fmt));
             }
 
+            if (pv->output.color_range != pv->input.color_range)
+            {
+                hb_dict_set_int(filter->settings, "color-range", pv->output.color_range);
+                hb_log("prefilter_vt: converting color range from %s", av_color_range_name(pv->input.color_range));
+            }
+
             hb_list_add(list_filter, filter);
             if (filter->init != NULL && filter->init(filter, &init))
             {
@@ -284,7 +289,7 @@ static int update(hb_filter_private_t *pv)
         {
             filter = hb_list_item(list_filter, ii);
             filter->done = &pv->done;
-            if (filter->post_init != NULL && filter->post_init(filter, job))
+            if (filter->post_init != NULL && filter->post_init(filter, pv->input.job))
             {
                 hb_log("prefilter_vt: failure to initialise filter '%s'", filter->name );
                 hb_list_rem(list_filter, filter);
@@ -308,14 +313,15 @@ static int update(hb_filter_private_t *pv)
                 fifo_last = fifo_in = filter->fifo_out;
             }
         }
-        pv->fifo_first = fifo_first;
-        pv->fifo_last  = fifo_last;
+        pv->fifo_first  = fifo_first;
+        pv->fifo_last   = fifo_last;
         pv->list_filter = list_filter;
 
-        pv->resample.width        = pv->input.geometry.width;
-        pv->resample.height       = pv->input.geometry.height;
-        pv->resample.rotation     = pv->output.job->title->rotation;
-        pv->resample.pix_fmt      = pv->input.pix_fmt;
+        pv->resample.width        = init.geometry.width;
+        pv->resample.height       = init.geometry.height;
+        pv->resample.color_range  = init.color_range;
+        pv->resample.rotation     = pv->rotation;
+        pv->resample.pix_fmt      = init.pix_fmt;
     }
 
     return 0;
@@ -330,17 +336,13 @@ static int prefilter_vt_work(hb_filter_object_t *filter,
 
     if (in->s.flags & HB_BUF_FLAG_EOF)
     {
-        if (pv->resample_needed)
-        {
-            filter_buf(pv, in);
-        }
         *buf_out = in;
         *buf_in = NULL;
         return HB_FILTER_DONE;
     }
 
     set_properties(pv, in);
-    update(pv);
+    update_filters(pv);
 
     if (pv->resample_needed)
     {
@@ -354,3 +356,17 @@ static int prefilter_vt_work(hb_filter_object_t *filter,
 
     return HB_FILTER_OK;
 }
+
+static const char prefilter_vt_template[] = "rotation=^(0|1|2|3)";
+
+hb_filter_object_t hb_filter_prefilter_vt =
+{
+    .id                = HB_FILTER_PRE_VT,
+    .enforce_order     = 1,
+    .name              = "Prefilter (VideoToolbox)",
+    .settings          = NULL,
+    .init              = prefilter_vt_init,
+    .work              = prefilter_vt_work,
+    .close             = prefilter_vt_close,
+    .settings_template = prefilter_vt_template,
+};
